@@ -597,8 +597,8 @@ def _para_get_column(arg_bag):
     primary_key, columns_to_get, col_filter = arg_bag
     consumed, return_row, next_token= client_global.get_row(_tablename, primary_key,columns_to_get,column_filter=col_filter)
     ### [0601] avoid errors from NA in the row
-    return [(x[0],x[1]) for x in return_row.primary_key] + [(x[0],x[1]) for x in return_row.attribute_columns]
-    #if not return_row is None:
+    if not return_row is None:
+        return [(x[0],x[1]) for x in return_row.primary_key] + [(x[0],x[1]) for x in return_row.attribute_columns]
     #   return ([x[1] for x in return_row.primary_key] + [x[1] for x in return_row.attribute_columns])
 
 
